@@ -39,7 +39,7 @@ class Explorer(object):
         
         i = 0
         while i < len(self.queue):
-            if self.step[self.queue[i]] >= max(min_step,(self.queue[i][1]-self.queue[i][0])//4):
+            if self.step[self.queue[i]] >= max(min_step,(self.queue[i][1]-self.queue[i][0])//8):
                 self.elaborate(self.queue[i][0],self.queue[i][1], True)
             else:
                 i += 1
@@ -49,7 +49,6 @@ class Explorer(object):
             step = self.step[(start,end)]
             if not step: break
             all = True
-            any = False
             for new_start, new_end in [
                      (start+step,end),
                      (start-step,end),
@@ -60,15 +59,15 @@ class Explorer(object):
                      (start-step,end+step),
                      (start-step,end-step),
                      ]:
-                if new_start >= new_end or new_end > self.size or new_start < 0: continue
-                any = True
-                if (new_start,new_end) in self.step: 
+                if new_start >= new_end or new_end > self.size or new_start < 0 or \
+                   (new_start,new_end) in self.step: 
                     all = False
                     continue
                 self.queue.append((new_start,new_end))
                 self.step[(new_start,new_end)] = step
             self.step[(start,end)] = step//2
-            if once or (any and all): break
+            if once or all: break
+            #if once: break
     
     def __iter__(self):
         return self
@@ -87,13 +86,13 @@ class Explorer(object):
 #pylab.show()
 #foo
 
-def find_peaks(depth, min_depth, power, min_initial_size=8):
+def find_peaks(depth, min_depth, power, depth_power=1.0, min_initial_size=8):
     """ Find peaks from a depth of coverage profile (list of integers). 
         """
-    integral = [0]
+    integral = [ 0.0 ]
     for i in xrange(len(depth)):
-        integral.append(integral[i]+depth[i]**power)
-        
+        integral.append(integral[i]+depth[i]**(power * depth_power))
+
     dominance = [ 0.0 ] * len(depth)            
     candidates = [ ]
     
@@ -101,19 +100,22 @@ def find_peaks(depth, min_depth, power, min_initial_size=8):
     for start,end in exp:
         width = end-start
         mean = (integral[end]-integral[start]) / width
-        score = (mean**(1.0/power)) * width
-    
-        any = False
+        #mean = sum(pdepth[start:end]) / width
+        if mean <= 0.0: continue
+        
+        score = math.log(mean) + math.log(width)*power
+        
         all = True
+        n = 0
         for i in xrange(start,end):
             if score > dominance[i]:
                 dominance[i] = score
-                any = True
+                n += 1
             else:
                 all = False
-#        if any:
-        if all:
+        if n*16 > end-start:
             exp.elaborate(start,end)
+        if all:
             if max(depth[start:end]) >= min_depth:
                 candidates.append((start,end,score))
     
@@ -137,7 +139,7 @@ def find_peaks(depth, min_depth, power, min_initial_size=8):
     '\n\n'
     
     'Algorithm details:'
-    ' Potential peaks are scored as the power-mean of the region (with exponent given by --power)'
+    ' Potential peaks are scored as the mean of the depths aveaged using a power mean'
     ' multiplied by the peak width.'
     ' A peak is reported if there is no higher scoring potential peak that overlaps it.'
     ' (A heuristic method is used to choose potential peaks to examine, the search is moderately thorough but'
@@ -148,7 +150,11 @@ def find_peaks(depth, min_depth, power, min_initial_size=8):
 @config.Float_flag(
     'power',
     '0 < power < 1\n'
-    'Larger values of power will suppress calling of peaks near taller peaks.'
+    'Larger values will suppress calling of peaks near taller peaks.'
+    )
+@config.Float_flag(
+    'depth_power',
+    'Smaller values will allow more variability within a peak.'
     )
 @config.Int_flag(
     'min_depth',
@@ -176,6 +182,7 @@ def find_peaks(depth, min_depth, power, min_initial_size=8):
 class Peaks(config.Action_with_prefix):
     min_depth = 25
     power = 0.1
+    depth_power = 0.5
     trim = 0
     filter = 'poly'
     strand_specific = True
@@ -255,11 +262,18 @@ class Peaks(config.Action_with_prefix):
             #pylab.plot(depth)
             
             n = 0
-            for start, end in find_peaks(depth, self.min_depth, self.power):
+            for start, end in find_peaks(depth, self.min_depth, self.power, self.depth_power):
                 #pylab.axvspan(start-0.5,end-0.5,alpha=0.25)
                 
                 n += 1
                 
+                if strand == -1:
+                    id = '%s-%d..%d' % (rname,start,end+1)
+                elif strand == 0:
+                    id = '%s.%d..%d' % (rname,start,end+1)
+                else:
+                    id = '%s+%d..%d' % (rname,start,end+1)
+                
                 ann = annotation.Annotation()
                 ann.source = 'nesoni'
                 ann.type = self.type
@@ -269,7 +283,7 @@ class Peaks(config.Action_with_prefix):
                 ann.strand = strand
                 ann.score = None
                 ann.phase = None
-                ann.attr = { 'id' : 'peak-%s-%d' % (rname,n) }
+                ann.attr = { 'id' : id }
                 print >> f, ann.as_gff()
             f.flush()
             
